==> webkit2gtk_2.40.5.orig.tar.xz: webkitgtk-2.40.5/Source/WebCore/platform/graphics/VideoTrackPrivate.h <==
/*
 * Copyright (C) 2012-2017 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#if ENABLE(VIDEO)

#include "PlatformVideoTrackConfiguration.h"
#include "TrackPrivateBase.h"
#include "VideoTrackPrivateClient.h"
#include <wtf/Function.h>

namespace WebCore {

class VideoTrackPrivate : public TrackPrivateBase {
public:
    void setClient(VideoTrackPrivateClient& client) { m_client = client; }
    void clearClient() { m_client = nullptr; }
    VideoTrackPrivateClient* client() const override { return m_client.get(); }

    virtual void setSelected(bool selected)
    {
        if (m_selected == selected)
            return;
        m_selected = selected;
        if (m_client)
            m_client->selectedChanged(m_selected);
        if (m_selectedChangedCallback)
            m_selectedChangedCallback(*this, m_selected);
    }
    virtual bool selected() const { return m_selected; }

    enum Kind { Alternative, Captions, Main, Sign, Subtitles, Commentary, None };
    virtual Kind kind() const { return None; }

#if !RELEASE_LOG_DISABLED
    const char* logClassName() const final { return "VideoTrackPrivate"; }
#endif

    using SelectedChangedCallback = Function<void(VideoTrackPrivate&, bool selected)>;
    void setSelectedChangedCallback(SelectedChangedCallback&& callback) { m_selectedChangedCallback = WTFMove(callback); }

    const PlatformVideoTrackConfiguration& configuration() const { return m_configuration; }
    void setConfiguration(PlatformVideoTrackConfiguration&& configuration)
    {
        if (configuration == m_configuration)
            return;
        m_configuration = WTFMove(configuration);
        if (m_client)
            m_client->configurationChanged(m_configuration);
    }
    
    bool operator==(const VideoTrackPrivate& track) const
    {
        return TrackPrivateBase::operator==(track)
            && configuration() == track.configuration()
            && kind() == track.kind();
    }

protected:
    VideoTrackPrivate() = default;

private:
    WeakPtr<VideoTrackPrivateClient> m_client { nullptr };
    bool m_selected { false };
    PlatformVideoTrackConfiguration m_configuration;

    SelectedChangedCallback m_selectedChangedCallback;
};

} // namespace WebCore

namespace WTF {

template<> struct EnumTraits<WebCore::VideoTrackPrivate::Kind> {
    using values = EnumValues<
        WebCore::VideoTrackPrivate::Kind,
        WebCore::VideoTrackPrivate::Kind::Alternative,
        WebCore::VideoTrackPrivate::Kind::Captions,
        WebCore::VideoTrackPrivate::Kind::Main,
        WebCore::VideoTrackPrivate::Kind::Sign,
        WebCore::VideoTrackPrivate::Kind::Subtitles,
        WebCore::VideoTrackPrivate::Kind::Commentary,
        WebCore::VideoTrackPrivate::Kind::None
    >;
};

} // namespace WTF

#endif

==> webkit2gtk_2.51.1.orig.tar.xz: webkitgtk-2.51.1/Source/WebCore/platform/graphics/VideoTrackPrivate.h <==
/*
 * Copyright (C) 2012-2017 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#if ENABLE(VIDEO)

#include <WebCore/PlatformVideoTrackConfiguration.h>
#include <WebCore/TrackPrivateBase.h>
#include <WebCore/VideoTrackPrivateClient.h>
#include <wtf/Function.h>
#include <wtf/TZoneMallocInlines.h>

namespace WebCore {

struct VideoInfo;

class VideoTrackPrivate : public TrackPrivateBase {
    WTF_MAKE_TZONE_ALLOCATED_INLINE(VideoTrackPrivate);
public:
    virtual void setSelected(bool selected)
    {
        if (m_selected == selected)
            return;
        m_selected = selected;
        notifyClients([selected](auto& client) {
            downcast<VideoTrackPrivateClient>(client).selectedChanged(selected);
        });
        if (m_selectedChangedCallback)
            m_selectedChangedCallback(*this, m_selected);
    }
    virtual bool selected() const { return m_selected; }

    enum class Kind : uint8_t { Alternative, Captions, Main, Sign, Subtitles, Commentary, None };
    virtual Kind kind() const { return Kind::None; }

#if !RELEASE_LOG_DISABLED
    ASCIILiteral logClassName() const final { return "VideoTrackPrivate"_s; }
#endif

    using SelectedChangedCallback = Function<void(VideoTrackPrivate&, bool selected)>;
    void setSelectedChangedCallback(SelectedChangedCallback&& callback) { m_selectedChangedCallback = WTFMove(callback); }

    const PlatformVideoTrackConfiguration& configuration() const { return m_configuration; }
    void setConfiguration(PlatformVideoTrackConfiguration&& configuration)
    {
        if (configuration == m_configuration)
            return;
        m_configuration = WTFMove(configuration);
        notifyClients([configuration = m_configuration](auto& client) {
            downcast<VideoTrackPrivateClient>(client).configurationChanged(configuration);
        });
    }
    
    bool operator==(const VideoTrackPrivate& track) const
    {
        return TrackPrivateBase::operator==(track)
            && configuration() == track.configuration()
            && kind() == track.kind();
    }

    Type type() const final { return Type::Video; }

    virtual void setFormatDescription(Ref<VideoInfo>&&) { }

protected:
    VideoTrackPrivate() = default;

private:
    bool m_selected { false };
    PlatformVideoTrackConfiguration m_configuration;

    SelectedChangedCallback m_selectedChangedCallback;
};

} // namespace WebCore

SPECIALIZE_TYPE_TRAITS_BEGIN(WebCore::VideoTrackPrivate)
static bool isType(const WebCore::TrackPrivateBase& track) { return track.type() == WebCore::TrackPrivateBase::Type::Video; }
SPECIALIZE_TYPE_TRAITS_END()

#endif
